==> estateplat-common-1.2.4-20231120.084040-1199-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxxInfo.java <==
package cn.gtmap.estateplat.model.server.core;


import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @version 1.0, 2020/12/12
 * @auther <a href="mailto:xusong@gtmap.cn" >xusong on 2020/12/12.</a>
 * @description 姑苏用于互联网的收费模式
 */
@Table(name = "BDC_SFXX_INFO")
public class BdcSfxxInfo {
    @Id
    private String orderno;
    private String sfxxid;
    private String unitno;
    private String unitname;
    private String receiveableamt;
    private String createtime;
    private String status;
    private String payername;
    private String payeraccountno;
    private String payerbankname;
    private String payertel;
    private String payeename;
    private String payeeaccountno;
    private String payeebankname;
    private String createuserid;
    private String remark;
    private String attachinfo;
    private String uniquemark;
    private String qrcodeurl;
    private String billcode;
    private String billno;
    private String random;
    private String paidtime;
    private String overdueamount;
    private String receivedamt;
    private String serialno;
    private String image;
    private String fpbh;
    private String fpyh;
    private String cpr;
    private String fkfs;
    private String acquire;
    private String remark2;
    private String payInfo;
    private String payerno;
    private String filetype;

    public String getPayInfo() {
        return payInfo;
    }

    public void setPayInfo(String payInfo) {
        this.payInfo = payInfo;
    }

    public String getPayerno() {
        return payerno;
    }

    public void setPayerno(String payerno) {
        this.payerno = payerno;
    }

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getOrderno() {
        return orderno;
    }

    public void setOrderno(String orderno) {
        this.orderno = orderno;
    }

    public String getUnitno() {
        return unitno;
    }

    public void setUnitno(String unitno) {
        this.unitno = unitno;
    }

    public String getUnitname() {
        return unitname;
    }

    public void setUnitname(String unitname) {
        this.unitname = unitname;
    }

    public String getReceiveableamt() {
        return receiveableamt;
    }

    public void setReceiveableamt(String receiveableamt) {
        this.receiveableamt = receiveableamt;
    }

    public String getCreatetime() {
        return createtime;
    }

    public void setCreatetime(String createtime) {
        this.createtime = createtime;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getPayername() {
        return payername;
    }

    public void setPayername(String payername) {
        this.payername = payername;
    }

    public String getPayeraccountno() {
        return payeraccountno;
    }

    public void setPayeraccountno(String payeraccountno) {
        this.payeraccountno = payeraccountno;
    }

    public String getPayerbankname() {
        return payerbankname;
    }

    public void setPayerbankname(String payerbankname) {
        this.payerbankname = payerbankname;
    }

    public String getPayertel() {
        return payertel;
    }

    public void setPayertel(String payertel) {
        this.payertel = payertel;
    }

    public String getPayeename() {
        return payeename;
    }

    public void setPayeename(String payeename) {
        this.payeename = payeename;
    }

    public String getPayeeaccountno() {
        return payeeaccountno;
    }

    public void setPayeeaccountno(String payeeaccountno) {
        this.payeeaccountno = payeeaccountno;
    }

    public String getPayeebankname() {
        return payeebankname;
    }

    public void setPayeebankname(String payeebankname) {
        this.payeebankname = payeebankname;
    }

    public String getCreateuserid() {
        return createuserid;
    }

    public void setCreateuserid(String createuserid) {
        this.createuserid = createuserid;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getAttachinfo() {
        return attachinfo;
    }

    public void setAttachinfo(String attachinfo) {
        this.attachinfo = attachinfo;
    }

    public String getUniquemark() {
        return uniquemark;
    }

    public void setUniquemark(String uniquemark) {
        this.uniquemark = uniquemark;
    }

    public String getQrcodeurl() {
        return qrcodeurl;
    }

    public void setQrcodeurl(String qrcodeurl) {
        this.qrcodeurl = qrcodeurl;
    }

    public String getBillcode() {
        return billcode;
    }

    public void setBillcode(String billcode) {
        this.billcode = billcode;
    }

    public String getBillno() {
        return billno;
    }

    public void setBillno(String billno) {
        this.billno = billno;
    }

    public String getRandom() {
        return random;
    }

    public void setRandom(String random) {
        this.random = random;
    }

    public String getPaidtime() {
        return paidtime;
    }

    public void setPaidtime(String paidtime) {
        this.paidtime = paidtime;
    }

    public String getOverdueamount() {
        return overdueamount;
    }

    public void setOverdueamount(String overdueamount) {
        this.overdueamount = overdueamount;
    }

    public String getReceivedamt() {
        return receivedamt;
    }

    public void setReceivedamt(String receivedamt) {
        this.receivedamt = receivedamt;
    }

    public String getSerialno() {
        return serialno;
    }

    public void setSerialno(String serialno) {
        this.serialno = serialno;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getFpbh() {
        return fpbh;
    }

    public void setFpbh(String fpbh) {
        this.fpbh = fpbh;
    }

    public String getFpyh() {
        return fpyh;
    }

    public void setFpyh(String fpyh) {
        this.fpyh = fpyh;
    }

    public String getCpr() {
        return cpr;
    }

    public void setCpr(String cpr) {
        this.cpr = cpr;
    }

    public String getFkfs() {
        return fkfs;
    }

    public void setFkfs(String fkfs) {
        this.fkfs = fkfs;
    }

    public String getAcquire() {
        return acquire;
    }

    public void setAcquire(String acquire) {
        this.acquire = acquire;
    }

    public String getRemark2() {
        return remark2;
    }

    public void setRemark2(String remark2) {
        this.remark2 = remark2;
    }

    public String getFiletype() {
        return filetype;
    }

    public void setFiletype(String filetype) {
        this.filetype = filetype;
    }
}

==> estateplat-common-1.2.4-20241031.032451-1259-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxxInfo.java <==
package cn.gtmap.estateplat.model.server.core;


import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @version 1.0, 2020/12/12
 * @auther <a href="mailto:xusong@gtmap.cn" >xusong on 2020/12/12.</a>
 * @description 姑苏用于互联网的收费模式
 */
@Table(name = "BDC_SFXX_INFO")
public class BdcSfxxInfo {
    @Id
    private String orderno;
    private String sfxxid;
    private String unitno;
    private String unitname;
    private String receiveableamt;
    private String createtime;
    private String status;
    private String payername;
    private String payeraccountno;
    private String payerbankname;
    private String payertel;
    private String payeename;
    private String payeeaccountno;
    private String payeebankname;
    private String createuserid;
    private String remark;
    private String attachinfo;
    private String uniquemark;
    private String qrcodeurl;
    private String billcode;
    private String billno;
    private String random;
    private String paidtime;
    private String overdueamount;
    private String receivedamt;
    private String serialno;
    private String image;
    private String fpbh;
    private String fpyh;
    private String cpr;
    private String fkfs;
    private String acquire;
    private String remark2;
    private String payInfo;
    private String payerno;
    private String filetype;
    private String proid;

    public String getPayInfo() {
        return payInfo;
    }

    public void setPayInfo(String payInfo) {
        this.payInfo = payInfo;
    }

    public String getPayerno() {
        return payerno;
    }

    public void setPayerno(String payerno) {
        this.payerno = payerno;
    }

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getOrderno() {
        return orderno;
    }

    public void setOrderno(String orderno) {
        this.orderno = orderno;
    }

    public String getUnitno() {
        return unitno;
    }

    public void setUnitno(String unitno) {
        this.unitno = unitno;
    }

    public String getUnitname() {
        return unitname;
    }

    public void setUnitname(String unitname) {
        this.unitname = unitname;
    }

    public String getReceiveableamt() {
        return receiveableamt;
    }

    public void setReceiveableamt(String receiveableamt) {
        this.receiveableamt = receiveableamt;
    }

    public String getCreatetime() {
        return createtime;
    }

    public void setCreatetime(String createtime) {
        this.createtime = createtime;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getPayername() {
        return payername;
    }

    public void setPayername(String payername) {
        this.payername = payername;
    }

    public String getPayeraccountno() {
        return payeraccountno;
    }

    public void setPayeraccountno(String payeraccountno) {
        this.payeraccountno = payeraccountno;
    }

    public String getPayerbankname() {
        return payerbankname;
    }

    public void setPayerbankname(String payerbankname) {
        this.payerbankname = payerbankname;
    }

    public String getPayertel() {
        return payertel;
    }

    public void setPayertel(String payertel) {
        this.payertel = payertel;
    }

    public String getPayeename() {
        return payeename;
    }

    public void setPayeename(String payeename) {
        this.payeename = payeename;
    }

    public String getPayeeaccountno() {
        return payeeaccountno;
    }

    public void setPayeeaccountno(String payeeaccountno) {
        this.payeeaccountno = payeeaccountno;
    }

    public String getPayeebankname() {
        return payeebankname;
    }

    public void setPayeebankname(String payeebankname) {
        this.payeebankname = payeebankname;
    }

    public String getCreateuserid() {
        return createuserid;
    }

    public void setCreateuserid(String createuserid) {
        this.createuserid = createuserid;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getAttachinfo() {
        return attachinfo;
    }

    public void setAttachinfo(String attachinfo) {
        this.attachinfo = attachinfo;
    }

    public String getUniquemark() {
        return uniquemark;
    }

    public void setUniquemark(String uniquemark) {
        this.uniquemark = uniquemark;
    }

    public String getQrcodeurl() {
        return qrcodeurl;
    }

    public void setQrcodeurl(String qrcodeurl) {
        this.qrcodeurl = qrcodeurl;
    }

    public String getBillcode() {
        return billcode;
    }

    public void setBillcode(String billcode) {
        this.billcode = billcode;
    }

    public String getBillno() {
        return billno;
    }

    public void setBillno(String billno) {
        this.billno = billno;
    }

    public String getRandom() {
        return random;
    }

    public void setRandom(String random) {
        this.random = random;
    }

    public String getPaidtime() {
        return paidtime;
    }

    public void setPaidtime(String paidtime) {
        this.paidtime = paidtime;
    }

    public String getOverdueamount() {
        return overdueamount;
    }

    public void setOverdueamount(String overdueamount) {
        this.overdueamount = overdueamount;
    }

    public String getReceivedamt() {
        return receivedamt;
    }

    public void setReceivedamt(String receivedamt) {
        this.receivedamt = receivedamt;
    }

    public String getSerialno() {
        return serialno;
    }

    public void setSerialno(String serialno) {
        this.serialno = serialno;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getFpbh() {
        return fpbh;
    }

    public void setFpbh(String fpbh) {
        this.fpbh = fpbh;
    }

    public String getFpyh() {
        return fpyh;
    }

    public void setFpyh(String fpyh) {
        this.fpyh = fpyh;
    }

    public String getCpr() {
        return cpr;
    }

    public void setCpr(String cpr) {
        this.cpr = cpr;
    }

    public String getFkfs() {
        return fkfs;
    }

    public void setFkfs(String fkfs) {
        this.fkfs = fkfs;
    }

    public String getAcquire() {
        return acquire;
    }

    public void setAcquire(String acquire) {
        this.acquire = acquire;
    }

    public String getRemark2() {
        return remark2;
    }

    public void setRemark2(String remark2) {
        this.remark2 = remark2;
    }

    public String getFiletype() {
        return filetype;
    }

    public void setFiletype(String filetype) {
        this.filetype = filetype;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
